@@ -8,6 +8,7 @@
 #include "src/stationchooser.h"
 #include "src/favouritestations.h"
 #include "src/departureboard.h"
+#include <QDBusConnection>
 
 namespace Ui {
     class Chooser;
@@ -20,10 +21,10 @@ public:
     ~Chooser();
 
 public slots:
-    void launchPlanner();
-
-    void stationSelected();
-    void editFavouriteDepartures();
+    void launchPlanner(); //Launches the journey planner
+    void stationSelected(); //Handles when a station departure board button is clicked
+    void editFavouriteDepartures(); //Handles when the user chooses to edit their favourite station
+    void chooseStation();
 
 protected:
     void changeEvent(QEvent *e);
@@ -39,7 +40,7 @@ private:
     FavouriteStations favouriteStations;
     QVector<QPushButton *> stationButtons;
 
-    DepartureBoard depatureBoard;
+    DepartureBoard * departureBoard;
 };
 
 #endif // CHOOSER_H
