@@ -18,10 +18,8 @@ public:
     int exec(QString names, QString codes);
 
 public slots:
-    void addFavourite();
-    void deleteFavourite();
-
-    void selectionChanged();
+    void addFavourite(); //When the user clicks the button to add a new favourite station
+    void deleteFavourite(); //When the user clicks the delete button
 
     void accept();
     void reject();
@@ -33,8 +31,8 @@ private:
     Ui::FavouriteStations *ui;
     QSettings settings;
 
-    QString names;
-    QString codes;
+    QString names; //The QSettings key for the favourite station names
+    QString codes; //The QSettings key for the favourite station CRS codes
 
     void save();
 };
